| clear_username | R Documentation |
Get your ICES username from the options.
Set the ICES user or logon name that will be used for requests
clear_username()
get_username()
set_username(username)
username |
the ices username you use to login to SharePoint for example. |
character scalar, the username
invisible value: the previous username that was set
## Not run:
get_username()
## End(Not run)
## Not run:
set_username("myusername")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.